.. module:: enaml.stdlib.task_dialog

=============================
enaml.stdlib.slider_transform
=============================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    TaskDialogIconArea
    TaskDialogInstructionArea
    TaskDialogContentArea
    TaskDialogCommandArea
    TaskDialogDetailsArea
    TaskDialogFootnoteArea
    TaskDialogBody


.. autoclass:: TaskDialogIconArea

.. autoclass:: TaskDialogInstructionArea

.. autoclass:: TaskDialogContentArea

.. autoclass:: TaskDialogCommandArea

.. autoclass:: TaskDialogDetailsArea

.. autoclass:: TaskDialogFootnoteArea

.. autoclass:: TaskDialogBody
